@@ -1,6 +1,6 @@
 package org.junit.rules;
 
-import org.junit.runners.model.FrameworkMethod;
+import org.junit.runner.Description;
 import org.junit.runners.model.Statement;
 
 /**
@@ -32,9 +32,12 @@ import org.junit.runners.model.Statement;
  * }
  * </pre>
  */
-public abstract class ExternalResource implements MethodRule {
-	public final Statement apply(final Statement base,
-			FrameworkMethod method, Object target) {
+public abstract class ExternalResource implements TestRule {
+	public Statement apply(Statement base, Description description) {
+		return statement(base);
+	}
+
+	private Statement statement(final Statement base) {
 		return new Statement() {
 			@Override
 			public void evaluate() throws Throwable {
