@@ -6,7 +6,7 @@ import static org.junit.matchers.JUnitMatchers.containsString;
 import org.junit.Ignore;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.rules.MethodRule;
+import org.junit.rules.TestRule;
 import org.junit.rules.Timeout;
 import org.junit.runner.JUnitCore;
 import org.junit.runner.Result;
@@ -15,7 +15,7 @@ public class TimeoutRuleTest {
 	public static class HasGlobalTimeout {
 		public static String log;
 		
-		@Rule public MethodRule globalTimeout = new Timeout(20);
+		@Rule public TestRule globalTimeout = new Timeout(20);
 		
 		@Test public void testInfiniteLoop1() {
 			log+= "ran1";
